@@ -5,7 +5,7 @@ from django.contrib.staticfiles.management.commands.collectstatic import (
 
 class Command(CollectStaticCommand):
     def set_options(self, *args, **options):
-        return_value = super(Command, self).set_options(*args, **options)
+        return_value = super().set_options(*args, **options)
         self.ignore_patterns += [
             "js/*.mjs",
             "js/modules/*",
