@@ -10,11 +10,12 @@ def load_last_name():
     try:
         with open(TRANSPILE_TIME_PATH, "rb") as f:
             _last_run = {**_last_run, **pickle.load(f)}
-    except (EOFError, IOError, TypeError):
+    except (EOFError, OSError, TypeError):
         pass
 
 
 def get_last_run(name):
+    global _last_run
     if name not in _last_run:
         load_last_name()
         if name not in _last_run:
